@@ -1,7 +1,4 @@
-context("Proportion of Ambiguous Clusterings")
-
 test_that("PAC can have different bounds", {
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(1)
   x <- replicate(100, rbinom(100, 4, 0.2))
   y <- consensus_matrix(x)
